@@ -154,6 +154,16 @@ public class FormatData_eu extends ListResourceBundle {
                "3Hh",
                "4Hh",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+            };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "g",
                "a",
@@ -168,12 +178,6 @@ public class FormatData_eu extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BG",
@@ -190,10 +194,6 @@ public class FormatData_eu extends ListResourceBundle {
                "GGGG. 'aroko' y('e')'ko' MMM d",
                "G y-MM-dd",
             };
-        final String[] metaValue_roc_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "R.O.C. aurretik",
                "R.O.C.",
@@ -202,7 +202,9 @@ public class FormatData_eu extends ListResourceBundle {
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "urtea" },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -213,6 +215,7 @@ public class FormatData_eu extends ListResourceBundle {
             { "narrow.Eras", metaValue_Eras },
             { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "timezone.regionFormat.standard", "{0}(e)ko ordu estandarra" },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "Japoniar egutegia" },
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
@@ -223,6 +226,7 @@ public class FormatData_eu extends ListResourceBundle {
                     "Kristo ondoren",
                 }
             },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -255,8 +259,10 @@ public class FormatData_eu extends ListResourceBundle {
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "minutua" },
             { "field.era", "aroa" },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "AM/PM" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "Minguo egutegia" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -265,13 +271,6 @@ public class FormatData_eu extends ListResourceBundle {
             { "field.second", "segundoa" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "%\u00a0#,##0",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamiar egutegia" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -285,30 +284,30 @@ public class FormatData_eu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0000",
-                    "00000",
-                    "000000",
-                    "0 milioi",
-                    "00 milioi",
-                    "000 milioi",
-                    "0000 milioi",
-                    "00000 milioi",
-                    "000000 milioi",
-                    "0 bilioi",
-                    "00 bilioi",
-                    "000 bilioi",
+                    "{one:0000 other:0000}",
+                    "{one:00000 other:00000}",
+                    "{one:000000 other:000000}",
+                    "{one:0' 'milioi other:0' 'milioi}",
+                    "{one:00' 'milioi other:00' 'milioi}",
+                    "{one:000' 'milioi other:000' 'milioi}",
+                    "{one:0000' 'milioi other:0000' 'milioi}",
+                    "{one:00000' 'milioi other:00000' 'milioi}",
+                    "{one:000000' 'milioi other:000000' 'milioi}",
+                    "{one:0' 'bilioi other:0' 'bilioi}",
+                    "{one:00' 'bilioi other:00' 'bilioi}",
+                    "{one:000' 'bilioi other:000' 'bilioi}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
-            { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
             { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
@@ -316,9 +315,12 @@ public class FormatData_eu extends ListResourceBundle {
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "asteguna" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -335,9 +337,9 @@ public class FormatData_eu extends ListResourceBundle {
             { "field.week", "astea" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "short.CompactNumberPatterns",
@@ -345,18 +347,18 @@ public class FormatData_eu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0000",
-                    "00000",
-                    "000000",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0000\u00a0M",
-                    "00000\u00a0M",
-                    "000000\u00a0M",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0000 other:0000}",
+                    "{one:00000 other:00000}",
+                    "{one:000000 other:000000}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0000\u00a0M other:0000\u00a0M}",
+                    "{one:00000\u00a0M other:00000\u00a0M}",
+                    "{one:000000\u00a0M other:000000\u00a0M}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -377,11 +379,20 @@ public class FormatData_eu extends ListResourceBundle {
             { "field.hour", "ordua" },
             { "calendarname.buddhist", "Egutegi budista" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "%\u00a0#,##0",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
