@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -85,6 +85,21 @@ public class FormatData_ja extends ListResourceBundle {
                "12\u6708",
                "",
             };
+        final String[] metaValue_MonthNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+               "5",
+               "6",
+               "7",
+               "8",
+               "9",
+               "10",
+               "11",
+               "12",
+               "",
+            };
         final String[] metaValue_DayNames = new String[] {
                "\u65e5\u66dc\u65e5",
                "\u6708\u66dc\u65e5",
@@ -109,12 +124,18 @@ public class FormatData_ja extends ListResourceBundle {
                "\u7b2c3\u56db\u534a\u671f",
                "\u7b2c4\u56db\u534a\u671f",
             };
-        final String[] metaValue_standalone_QuarterAbbreviations = new String[] {
+        final String[] metaValue_QuarterAbbreviations = new String[] {
                "Q1",
                "Q2",
                "Q3",
                "Q4",
             };
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u5348\u524d",
                "\u5348\u5f8c",
@@ -135,16 +156,14 @@ public class FormatData_ja extends ListResourceBundle {
                "{1} {0}",
                "{1} {0}",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u4ecf\u66a6",
             };
+        final String[] metaValue_java_time_buddhist_Eras = new String[] {
+               "BC",
+               "BE",
+            };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
                "GGGGy\u5e74M\u6708d\u65e5EEEE",
                "GGGGy\u5e74M\u6708d\u65e5",
@@ -196,23 +215,27 @@ public class FormatData_ja extends ListResourceBundle {
                "\u30ba\u30eb\u30fb\u30d2\u30c3\u30b8\u30e3",
                "",
             };
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
+               "",
+               "AH",
+            };
         final String metaValue_calendarname_gregorian = "\u897f\u66a6(\u30b0\u30ec\u30b4\u30ea\u30aa\u66a6)";
         final String[] metaValue_short_CompactNumberPatterns = new String[] {
                "",
                "",
                "",
-               "0",
-               "0\u4e07",
-               "00\u4e07",
-               "000\u4e07",
-               "0000\u4e07",
-               "0\u5104",
-               "00\u5104",
-               "000\u5104",
-               "0000\u5104",
-               "0\u5146",
-               "00\u5146",
-               "000\u5146",
+               "{other:0}",
+               "{other:0\u4e07}",
+               "{other:00\u4e07}",
+               "{other:000\u4e07}",
+               "{other:0000\u4e07}",
+               "{other:0\u5104}",
+               "{other:00\u5104}",
+               "{other:000\u5104}",
+               "{other:0000\u5104}",
+               "{other:0\u5146}",
+               "{other:00\u5146}",
+               "{other:000\u5146}",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -220,6 +243,7 @@ public class FormatData_ja extends ListResourceBundle {
             { "field.year", "\u5e74" },
             { "calendarname.islamic-umalqura", "\u30a4\u30b9\u30e9\u30e0\u66a6(\u30a6\u30f3\u30e0\u30fb\u30a2\u30eb\u30af\u30e9\u30fc)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -229,9 +253,10 @@ public class FormatData_ja extends ListResourceBundle {
                     "GGGGGy/M/d",
                 }
             },
-            { "standalone.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "japanese.narrow.Eras", metaValue_java_time_japanese_narrow_Eras },
+            { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.islamic-civil", "\u30a4\u30b9\u30e9\u30e0\u6b74(\u5b9a\u5468\u671f\u3001\u516c\u6c11\u7d00\u5143)" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -249,7 +274,9 @@ public class FormatData_ja extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras", metaValue_long_Eras },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -270,6 +297,7 @@ public class FormatData_ja extends ListResourceBundle {
                     "NaN",
                 }
             },
+            { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns",
                 new String[] {
                     "GGGGy\u5e74M\u6708d\u65e5EEEE",
@@ -285,22 +313,34 @@ public class FormatData_ja extends ListResourceBundle {
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u5348\u524d/\u5348\u5f8c" },
             { "islamic.MonthNames", metaValue_islamic_MonthNames },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "\u4e2d\u83ef\u6c11\u56fd\u66a6" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u6708" },
             { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "\u79d2" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayAbbreviations },
-            { "NumberPatterns",
+            { "islamic.MonthNarrows",
                 new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0%",
+                    "1",
+                    "2",
+                    "3",
+                    "4",
+                    "5",
+                    "6",
+                    "7",
+                    "8",
+                    "9",
+                    "10",
+                    "11",
+                    "12",
+                    "",
                 }
             },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayAbbreviations },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u30a4\u30b9\u30e9\u30e0\u66a6" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
@@ -310,10 +350,11 @@ public class FormatData_ja extends ListResourceBundle {
             { "standalone.MonthAbbreviations", metaValue_MonthNames },
             { "long.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "timezone.regionFormat", "{0}\u6642\u9593" },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "standalone.DayNarrows", metaValue_DayAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -323,29 +364,35 @@ public class FormatData_ja extends ListResourceBundle {
             { "islamic.DayNarrows", metaValue_DayAbbreviations },
             { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "\u30bf\u30a4\u30e0\u30be\u30fc\u30f3" },
-            { "japanese.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
             { "roc.DayNames", metaValue_DayNames },
             { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_roc_DatePatterns },
             { "field.weekday", "\u66dc\u65e5" },
             { "japanese.MonthAbbreviations", metaValue_MonthNames },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_standalone_QuarterAbbreviations },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "java.time.japanese.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
+            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
             { "field.week", "\u9031" },
+            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.DayNarrows", metaValue_DayAbbreviations },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_roc_DatePatterns },
@@ -359,6 +406,7 @@ public class FormatData_ja extends ListResourceBundle {
             },
             { "short.CompactNumberPatterns", metaValue_short_CompactNumberPatterns },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
             { "timezone.regionFormat.daylight", "{0}\u590f\u6642\u9593" },
             { "DatePatterns",
                 new String[] {
@@ -375,12 +423,23 @@ public class FormatData_ja extends ListResourceBundle {
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "\u6642" },
             { "islamic.MonthAbbreviations", metaValue_islamic_MonthNames },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u4ecf\u66a6" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0%",
+                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayAbbreviations },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayAbbreviations },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
+            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.Eras", metaValue_java_time_japanese_long_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
