@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,6 +70,7 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_cs extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_ccp = "\u010dakma";
         final String metaValue_kpe = "kpelle";
         final String metaValue_nqo = "n\u2019ko";
         final String metaValue_vai = "vai";
@@ -85,6 +86,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "Tagb", "tagbanwa" },
             { "Zsye", "emod\u017ei" },
             { "xmf", "mingrel\u0161tina" },
+            { "ccp", metaValue_ccp },
             { "egy", "egypt\u0161tina star\u00e1" },
             { "raj", "r\u00e1d\u017east\u00e1n\u0161tina" },
             { "Phag", "phags-pa" },
@@ -393,7 +395,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "ale", "aleut\u0161tina" },
             { "Thai", "thajsk\u00e9" },
             { "type.nu.vaii", "Vaisk\u00e9 \u010d\u00edslice" },
-            { "MK", "Makedonie" },
+            { "MK", "Severn\u00ed Makedonie" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Barma)" },
             { "MN", "Mongolsko" },
@@ -531,7 +533,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "SM", "San Marino" },
             { "SN", "Senegal" },
             { "SO", "Som\u00e1lsko" },
-            { "arn", "mapudungun\u0161tina" },
+            { "arn", "mapudungun" },
             { "arp", "arapa\u017e\u0161tina" },
             { "type.nu.taml", "Tamilsk\u00e9 tradi\u010dn\u00ed \u010d\u00edslice" },
             { "SR", "Surinam" },
@@ -540,7 +542,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "ST", "Svat\u00fd Tom\u00e1\u0161 a Princ\u016fv ostrov" },
             { "arq", "arab\u0161tina (al\u017e\u00edrsk\u00e1)" },
             { "SV", "Salvador" },
-            { "ars", "arab\u0161tina (nad\u017ed)" },
+            { "ars", "arab\u0161tina (Nad\u017ed)" },
             { "SX", "Svat\u00fd Martin (Nizozemsko)" },
             { "SY", "S\u00fdrie" },
             { "yao", "jao\u0161tina" },
@@ -635,7 +637,9 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "Bass", "bassa vah" },
             { "wal", "wolajt\u0161tina" },
             { "was", "wa\u0161tina" },
+            { "XA", "simulovan\u00e1 diakritika" },
             { "war", "waraj\u0161tina" },
+            { "XB", "simulovan\u00fd obousm\u011brn\u00fd z\u00e1pis" },
             { "awa", "awadh\u0161tina" },
             { "061", "Polyn\u00e9sie" },
             { "XK", "Kosovo" },
@@ -1096,9 +1100,9 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "dyo", "jola-fonyi" },
             { "type.nu.jpan", "Japonsk\u00e9 \u010d\u00edslice" },
             { "tr", "ture\u010dtina" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "komor\u0161tina" },
-            { "Cakm", "\u010dakma" },
             { "tt", "tatar\u0161tina" },
             { "dyu", "djula" },
             { "tw", "twi" },
