@@ -322,7 +322,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "SV", "Salv\u00e1dor" },
             { "SX", "Sv\u00e4t\u00fd Martin (hol.)" },
             { "SY", "S\u00fdria" },
-            { "SZ", "Svazijsko" },
+            { "SZ", "Eswatini" },
             { "TA", "Tristan da Cunha" },
             { "TC", "Turks a Caicos" },
             { "TD", "\u010cad" },
@@ -356,6 +356,8 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "VU", "Vanuatu" },
             { "WF", "Wallis a Futuna" },
             { "WS", "Samoa" },
+            { "XA", "falo\u0161n\u00e1 diakritika" },
+            { "XB", "obr\u00e1tenie sprava do\u013eava" },
             { "XK", "Kosovo" },
             { "YE", "Jemen" },
             { "YT", "Mayotte" },
@@ -594,6 +596,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "car", "karib\u010dina" },
             { "cay", "kajug\u010dina" },
             { "cch", "atsam" },
+            { "ccp", "\u010dakma" },
             { "ceb", "cebu\u00e1n\u010dina" },
             { "cgg", "kiga" },
             { "chb", "\u010dib\u010da" },
@@ -865,7 +868,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "zap", "zapot\u00e9\u010dtina" },
             { "zbl", "syst\u00e9m Bliss" },
             { "zen", "zenaga" },
-            { "zgh", "tuareg\u010dina (\u0161tandardn\u00e1 marock\u00e1)" },
+            { "zgh", "tuareg\u010dina (marock\u00e1 \u0161tandardn\u00e1)" },
             { "zun", "zuni\u0161tina" },
             { "zxx", "bez jazykov\u00e9ho obsahu" },
             { "zza", "zaza" },
@@ -948,8 +951,8 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "key.lb", "\u0161t\u00fdl koncov riadka" },
             { "key.ms", "mern\u00e1 s\u00fastava" },
             { "key.nu", "\u010d\u00edsla" },
-            { "key.tz", "\u010casov\u00e9 p\u00e1smo" },
-            { "key.va", "Variant miestneho nastavenia" },
+            { "key.tz", "\u010dasov\u00e9 p\u00e1smo" },
+            { "key.va", "variant miestneho nastavenia" },
             { "nds_NL", "doln\u00e1 sa\u0161tina" },
             { "zh_Hans", "\u010d\u00edn\u0161tina (zjednodu\u0161en\u00e1)" },
             { "zh_Hant", "\u010d\u00edn\u0161tina (tradi\u010dn\u00e1)" },
