@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -70,14 +70,6 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Argentina = new String[] {
-               "Argentina Standard Time",
-               "",
-               "Argentina Summer Time",
-               "",
-               "Argentina Time",
-               "",
-            };
         final String[] America_Eastern = new String[] {
                "",
                "EST",
@@ -163,6 +155,16 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
             { "America/St_Johns", Newfoundland },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "UTC",
                 new String[] {
                     "",
@@ -180,10 +182,19 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
             { "America/El_Salvador", America_Central },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/Coral_Harbour", America_Eastern },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
             { "America/Guatemala", America_Central },
-            { "America/Argentina/La_Rioja", Argentina },
             { "America/Puerto_Rico", Atlantic },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cayman", America_Eastern },
@@ -206,12 +217,11 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "America/Nome", Alaska },
             { "America/Ojinaga", America_Mountain },
+            { "America/Nome", Alaska },
             { "America/Tegucigalpa", America_Central },
             { "America/Rainy_River", America_Central },
             { "SystemV/AST4", Atlantic },
-            { "America/Argentina/Ushuaia", Argentina },
             { "America/Yellowknife", America_Mountain },
             { "America/Juneau", Alaska },
             { "Europe/Astrakhan",
@@ -225,8 +235,6 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                 }
             },
             { "America/Indiana/Vevay", America_Eastern },
-            { "America/Jujuy", Argentina },
-            { "America/Buenos_Aires", Argentina },
             { "Antarctica/Palmer",
                 new String[] {
                     "",
@@ -243,10 +251,8 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
             { "America/Grand_Turk", America_Eastern },
             { "America/Metlakatla", Alaska },
             { "America/Pangnirtung", America_Eastern },
-            { "EST", America_Eastern },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Creston", America_Mountain },
-            { "MST", America_Mountain },
             { "America/Punta_Arenas",
                 new String[] {
                     "",
@@ -261,15 +267,13 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "America/Kralendijk", Atlantic },
             { "America/Mexico_City", America_Central },
-            { "America/Argentina/Salta", Argentina },
             { "America/Antigua", Atlantic },
             { "America/Montreal", America_Eastern },
-            { "America/Argentina/San_Juan", Argentina },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
             { "America/Moncton", Atlantic },
+            { "America/Blanc-Sablon", Atlantic },
             { "America/Indiana/Winamac", America_Eastern },
             { "SystemV/MST7MDT", America_Mountain },
             { "America/St_Vincent", Atlantic },
@@ -296,21 +300,10 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                     "HST",
                 }
             },
-            { "America/Menominee", America_Central },
             { "America/Yakutat", Alaska },
+            { "America/Menominee", America_Central },
             { "America/Adak", Hawaii_Aleutian },
-            { "America/Argentina/Tucuman", Argentina },
             { "timezone.excity.Asia/Rangoon", "Rangoon" },
-            { "HST",
-                new String[] {
-                    "",
-                    "HST",
-                    "",
-                    "HDT",
-                    "",
-                    "HST",
-                }
-            },
             { "America/Resolute", America_Central },
             { "SystemV/YST9YDT", Alaska },
             { "Europe/Ulyanovsk",
@@ -323,11 +316,9 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "America/Argentina/Rio_Gallegos", Argentina },
             { "SystemV/EST5", America_Eastern },
             { "America/Merida", America_Central },
             { "America/Edmonton", America_Mountain },
-            { "America/Catamarca", Argentina },
             { "America/Santo_Domingo", Atlantic },
             { "SystemV/MST7", America_Mountain },
             { "America/St_Kitts", Atlantic },
@@ -335,10 +326,8 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
             { "America/Glace_Bay", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Guadeloupe", Atlantic },
-            { "America/Cordoba", Argentina },
             { "SystemV/PST8PDT", America_Pacific },
             { "America/Port-au-Prince", America_Eastern },
-            { "America/Mendoza", Argentina },
             { "America/St_Barthelemy", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Regina", America_Central },
@@ -353,8 +342,8 @@ public class TimeZoneNames_en_CA extends TimeZoneNamesBundle {
                 }
             },
             { "America/Boise", America_Mountain },
-            { "America/North_Dakota/New_Salem", America_Central },
             { "EST5EDT", America_Eastern },
+            { "America/North_Dakota/New_Salem", America_Central },
             { "America/Dawson_Creek", America_Mountain },
             { "America/St_Thomas", Atlantic },
             { "Atlantic/Bermuda", Atlantic },
