@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "Falkland Adalar\u0131 Saati",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Butan Saati",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia Standart Saati",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "Apia Saati",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Butan Saati",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru Saati",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolombiya Standart Saati",
+        final String[] Australia_Eastern = new String[] {
+               "Do\u011fu Avustralya Standart Saati",
                "",
-               "Kolombiya Yaz Saati",
+               "Do\u011fu Avustralya Yaz Saati",
                "",
-               "Kolombiya Saati",
+               "Do\u011fu Avustralya Saati",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Do\u011fu Avustralya Standart Saati",
+        final String[] Colombia = new String[] {
+               "Kolombiya Standart Saati",
                "",
-               "Do\u011fu Avustralya Yaz Saati",
+               "Kolombiya Yaz Saati",
                "",
-               "Do\u011fu Avustralya Saati",
+               "Kolombiya Saati",
                "",
             };
         final String[] Chile = new String[] {
@@ -710,14 +710,6 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "Paraguay Saati",
                "",
             };
-        final String[] Casey = new String[] {
-               "Casey Saati",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "Malezya Saati",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Kuzeybat\u0131 Meksika Standart Saati",
+        final String[] Volgograd = new String[] {
+               "Volgograd Standart Saati",
                "",
-               "Kuzeybat\u0131 Meksika Yaz Saati",
+               "Volgograd Yaz Saati",
                "",
-               "Kuzeybat\u0131 Meksika Saati",
+               "Volgograd Saati",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "Paskalya Adas\u0131 Saati",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Kuzeybat\u0131 Meksika Standart Saati",
+               "",
+               "Kuzeybat\u0131 Meksika Yaz Saati",
+               "",
+               "Kuzeybat\u0131 Meksika Saati",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville Saati",
                "",
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                "Samara Saati",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Pyongyang Saati",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Hindistan Standart Saati",
                "",
@@ -1268,7 +1260,16 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1352,7 +1353,6 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1429,8 +1429,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "America/Indiana/Vevay", America_Eastern },
             { "timezone.excity.America/Grenada", "Grenada" },
             { "timezone.excity.Asia/Phnom_Penh", "Phnom Penh" },
-            { "timezone.excity.Europe/Rome", "Roma" },
             { "timezone.excity.Asia/Hebron", "El Halil" },
+            { "timezone.excity.Europe/Rome", "Roma" },
             { "Asia/Jakarta", Indonesia_Western },
             { "timezone.excity.Antarctica/Mawson", "Mawson" },
             { "timezone.excity.Asia/Karachi", "Kara\u00e7i" },
@@ -1461,12 +1461,12 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Sao Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Akra" },
             { "timezone.excity.Etc/Unknown", "Bilinmeyen \u015eehir" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1526,8 +1526,17 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Aqtobe", "Akt\u00f6be" },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "L\u00fcksemburg" },
             { "America/Cayman", America_Eastern },
@@ -1682,9 +1691,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Maputo", "Maputo" },
             { "timezone.excity.Africa/Luanda", "Luanda" },
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
-            { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
+            { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1721,6 +1729,7 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1769,8 +1778,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "Pacific/Rarotonga", Cook },
             { "America/Guatemala", America_Central },
             { "Australia/Hobart", Australia_Eastern },
-            { "timezone.excity.Europe/Skopje", "\u00dcsk\u00fcp" },
             { "timezone.excity.America/Chihuahua", "Chihuahua" },
+            { "timezone.excity.Europe/Skopje", "\u00dcsk\u00fcp" },
             { "America/Belize", America_Central },
             { "America/Managua", America_Central },
             { "America/Indiana/Petersburg", America_Eastern },
@@ -1851,8 +1860,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "America/Havana", Cuba },
             { "timezone.excity.America/Edmonton", "Edmonton" },
             { "timezone.excity.Africa/Sao_Tome", "Sao Tome" },
-            { "timezone.excity.America/Dawson", "Dawson" },
             { "timezone.excity.Africa/Abidjan", "Abidjan" },
+            { "timezone.excity.America/Dawson", "Dawson" },
             { "America/Barbados", Atlantic },
             { "timezone.excity.America/Guadeloupe", "Guadeloupe" },
             { "timezone.excity.Africa/Freetown", "Freetown" },
@@ -1892,7 +1901,7 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1916,7 +1925,7 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Atina" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1938,7 +1947,7 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Kud\u00fcs" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riyad" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2064,8 +2073,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Blantyre", "Blantyre" },
             { "timezone.excity.Europe/Malta", "Malta" },
             { "Pacific/Tarawa", Gilbert_Islands },
-            { "timezone.excity.Australia/Sydney", "Sidney" },
             { "timezone.excity.Asia/Qatar", "Katar" },
+            { "timezone.excity.Australia/Sydney", "Sidney" },
             { "timezone.excity.America/Sitka", "Sitka" },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Davis" },
@@ -2080,7 +2089,7 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "timezone.excity.America/Argentina/La_Rioja", "La Rioja" },
             { "Africa/Luanda", Africa_Western },
             { "timezone.excity.Europe/Mariehamn", "Mariehamn" },
-            { "timezone.excity.America/St_Barthelemy", "Saint Barth\u00e9lemy" },
+            { "timezone.excity.America/St_Barthelemy", "Saint Barthelemy" },
             { "timezone.excity.America/Santiago", "Santiago" },
             { "Asia/Muscat", Gulf },
             { "Asia/Bahrain", Arabian },
@@ -2099,7 +2108,7 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "\u0130stanbul" },
             { "America/Rio_Branco", Acre },
@@ -2121,8 +2130,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "Asia/Kamchatka", Kamchatka },
             { "timezone.excity.Asia/Samarkand", "Semerkand" },
             { "Africa/Khartoum", Africa_Central },
-            { "timezone.excity.Australia/Adelaide", "Adelaide" },
             { "timezone.excity.Asia/Singapore", "Singapur" },
+            { "timezone.excity.Australia/Adelaide", "Adelaide" },
             { "Europe/Belgrade", Europe_Central },
             { "timezone.excity.Europe/Vienna", "Viyana" },
             { "Africa/Bissau", GMT },
@@ -2154,8 +2163,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
             { "timezone.excity.Antarctica/Syowa", "Showa" },
             { "timezone.excity.America/Jamaica", "Jamaika" },
-            { "timezone.excity.America/Hermosillo", "Hermosillo" },
             { "timezone.excity.Pacific/Funafuti", "Funafuti" },
+            { "timezone.excity.America/Hermosillo", "Hermosillo" },
             { "timezone.excity.Europe/Podgorica", "Podgorica" },
             { "timezone.excity.Indian/Reunion", "Reunion" },
             { "timezone.excity.Pacific/Noumea", "Noumea" },
@@ -2208,8 +2217,8 @@ public class TimeZoneNames_tr extends TimeZoneNamesBundle {
             },
             { "Asia/Anadyr", Anadyr },
             { "timezone.excity.Indian/Chagos", "Chagos" },
-            { "timezone.excity.Asia/Kabul", "Kabil" },
             { "timezone.excity.America/Iqaluit", "Iqaluit" },
+            { "timezone.excity.Asia/Kabul", "Kabil" },
             { "America/Winnipeg", America_Central },
             { "timezone.excity.Europe/Amsterdam", "Amsterdam" },
             { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
